@@ -1230,16 +1230,6 @@ class TestCredentials(object):
             )
             _ = credentials.revoke(None)
 
-    @mock.patch.dict(os.environ, {"GOOGLE_EXTERNAL_ACCOUNT_ALLOW_EXECUTABLES": "1"})
-    def test_retrieve_subject_token_python_2(self):
-        with mock.patch("sys.version_info", (2, 7)):
-            credentials = self.make_pluggable(credential_source=self.CREDENTIAL_SOURCE)
-
-            with pytest.raises(exceptions.RefreshError) as excinfo:
-                _ = credentials.retrieve_subject_token(None)
-
-            assert excinfo.match(r"Pluggable auth is only supported for python 3.7+")
-
     @mock.patch.dict(os.environ, {"GOOGLE_EXTERNAL_ACCOUNT_ALLOW_EXECUTABLES": "1"})
     def test_retrieve_subject_token_with_quoted_command(self):
         command_with_spaces = '"/path/with spaces/to/executable" "arg with spaces"'
@@ -1269,17 +1259,3 @@ class TestCredentials(object):
                 stderr=subprocess.STDOUT,
                 env=mock.ANY,
             )
-
-    @mock.patch.dict(os.environ, {"GOOGLE_EXTERNAL_ACCOUNT_ALLOW_EXECUTABLES": "1"})
-    def test_revoke_subject_token_python_2(self):
-        with mock.patch("sys.version_info", (2, 7)):
-            credentials = self.make_pluggable(
-                audience=WORKFORCE_AUDIENCE,
-                credential_source=self.CREDENTIAL_SOURCE,
-                interactive=True,
-            )
-
-            with pytest.raises(exceptions.RefreshError) as excinfo:
-                _ = credentials.revoke(None)
-
-            assert excinfo.match(r"Pluggable auth is only supported for python 3.7+")
